@@ -3,18 +3,18 @@ from __future__ import annotations
 import subprocess as sp
 import sys
 
-from ..environment import (
-    Environment,
-    Dependency,
-    LibraryDependency,
-    ProgramDependency,
-    Installer,
-    GNUInstaller,
-    OpenBLASInstaller,
-)
 from ...errors import InstallError, UninstallError
+from ..environment import (
+    Dependency,
+    Environment,
+    GNUInstaller,
+    Installer,
+    LibraryDependency,
+    OpenBLASInstaller,
+    ProgramDependency,
+)
 
-marabou_runner = """#!{python_venv}/bin/python
+MARABOU_RUNNER = """#!{python_venv}/bin/python
 import argparse
 import numpy as np
 
@@ -39,7 +39,7 @@ def main(args):
     network = Marabou.read_onnx(args.model)
 
     inputVars = network.inputVars[0]
-    outputVars = network.outputVars
+    outputVars = network.outputVars[0]
 
     for x, l, u in zip(inputVars.flatten(), lb, ub):
         network.setLowerBound(x, l)
@@ -53,21 +53,20 @@ def main(args):
 
     options = MarabouCore.Options()
     options._numWorkers = args.num_workers
-    result = network.solve(options=options)
-
-    is_unsafe = bool(result[0])
-    print("UNSAFE" if is_unsafe else "SAFE")
+    result_str, vals, stats = network.solve(options=options)
+    print(result_str)
+    is_unsafe = result_str == "sat"
 
     if args.output is not None:
         cex = None
         if is_unsafe:
             cex = np.zeros_like(inputVars, dtype=np.float32)
             for flat_index, multi_index in enumerate(np.ndindex(cex.shape)):
-                cex[multi_index] = result[0][flat_index]
+                cex[multi_index] = vals[flat_index]
             print(cex)
         np.save(
             args.output,
-            (is_unsafe, cex),
+            (result_str, cex),
         )
 
 
@@ -78,7 +77,7 @@ if __name__ == "__main__":
 
 class MarabouInstaller(Installer):
     def run(self, env: Environment, dependency: Dependency):
-        commit_hash = "c179c5db1af2cb66bc45c4ed7fbb7a1897e67233"
+        commit_hash = "492c1b8c703c8a383f421468a104c34710e6d26d"
 
         cache_dir = env.cache_dir / f"marabou-{commit_hash}"
         cache_dir.mkdir(exist_ok=True, parents=True)
@@ -93,7 +92,14 @@ class MarabouInstaller(Installer):
         assert libopenblas_path is not None
         openblas_path = libopenblas_path.parent.parent
 
-        python_major_version, python_minor_version = sys.version_info[:2]
+        python_major_version, python_minor_version, *_ = sys.version_info
+        python_version = f"python{python_major_version}.{python_minor_version}"
+        site_packages_dir = f"{verifier_venv_path}/lib/{python_version}/site-packages/"
+
+        marabou_url = "https://github.com/NeuralNetworkVerification/Marabou.git"
+
+        build_dir = cache_dir / f"Marabou/build-{python_version}"
+        openblas_vars = f"-D OPENBLAS_DIR={build_dir}/OpenBlas"
 
         commands = [
             "set -ex",
@@ -102,29 +108,37 @@ class MarabouInstaller(Installer):
             "python -m venv marabou",
             ". marabou/bin/activate",
             "pip install --upgrade pip",
-            'pip install "numpy>=1.19,<1.22" "onnx>=1.8,<1.11" "onnxruntime>=1.7,<1.11"',
+            (
+                "pip install"
+                ' "numpy>=1.19,<1.22"'
+                ' "onnx>=1.8,<1.12"'
+                ' "onnxruntime>=1.7,<1.12"'
+                ' "protobuf<=3.20"'
+            ),
             f"cd {cache_dir}",
-            "rm -rf Marabou",
-            "git clone https://github.com/NeuralNetworkVerification/Marabou.git",
+            f"if [ ! -e Marabou ]",
+            f"then git clone {marabou_url}",
             "cd Marabou",
             f"git checkout {commit_hash}",
-            "rm -rf build",
-            "mkdir -p build",
-            "cd build",
+            "fi",
+            f"if [ ! -e {build_dir} ]",
+            f"then mkdir -p {build_dir}",
+            f"cd {build_dir}",
             "mkdir -p OpenBlas",
-            f"rm -f {cache_dir}/Marabou/build/OpenBlas/installed",
-            f"ln -s {openblas_path} {cache_dir}/Marabou/build/OpenBlas/installed",
-            f"cmake -D OPENBLAS_DIR={cache_dir}/Marabou/build/OpenBlas ..",
+            f"ln -s {openblas_path} {build_dir}/OpenBlas/installed",
+            f"cmake {openblas_vars} ..",
             "cmake --build .",
-            f"cp -r ../maraboupy {verifier_venv_path}/lib/python{python_major_version}.{python_minor_version}/site-packages/",
+            f"else cd {build_dir}",
+            "fi",
+            f"cp -r ../maraboupy {site_packages_dir}",
         ]
         install_script = "; ".join(commands)
         proc = sp.run(install_script, shell=True, env=env.vars())
         if proc.returncode != 0:
-            raise InstallError(f"Installation of marabou failed")
+            raise InstallError("Installation of marabou failed")
 
         with open(installation_path / "marabou", "w+") as f:
-            f.write(marabou_runner.format(python_venv=verifier_venv_path))
+            f.write(MARABOU_RUNNER.format(python_venv=verifier_venv_path))
         (installation_path / "marabou").chmod(0o700)
 
 
@@ -148,7 +162,10 @@ def install(env: Environment):
                     installer=GNUInstaller(
                         "cmake",
                         "3.18.2",
-                        "https://github.com/Kitware/CMake/releases/download/v3.18.2/cmake-3.18.2.tar.gz",
+                        (
+                            "https://github.com/Kitware/CMake/"
+                            "releases/download/v3.18.2/cmake-3.18.2.tar.gz"
+                        ),
                     ),
                     min_version="3.12.0",
                 ),
