@@ -2,32 +2,27 @@ from __future__ import annotations
 
 import subprocess as sp
 
+from ...errors import InstallError, UninstallError
 from ..environment import (
-    Environment,
     Dependency,
-    HeaderDependency,
-    LibraryDependency,
-    ProgramDependency,
-    Installer,
+    Environment,
     GNUInstaller,
     GurobiInstaller,
+    HeaderDependency,
+    Installer,
+    LibraryDependency,
+    ProgramDependency,
 )
-from ...errors import InstallError, UninstallError
 
-mipverify_runner = """#!/bin/bash
+MIPVERIFY_RUNNER = """#!/bin/bash
 export GUROBI_HOME={gurobi_home}
 cd {venv_path}
-./julia --project=. $@
+./julia --project=. -g 0 --track-allocation=none --code-coverage=none -O0 $@
 """
 
 
 class MIPVerifyInstaller(Installer):
     def run(self, env: Environment, dependency: Dependency):
-        commit_hash = "36fd890"
-
-        cache_dir = env.cache_dir / f"mipverify-{commit_hash}"
-        cache_dir.mkdir(exist_ok=True, parents=True)
-
         verifier_venv_path = env.env_dir / "verifier_virtualenvs" / "mipverify"
         verifier_venv_path.parent.mkdir(exist_ok=True, parents=True)
 
@@ -38,6 +33,8 @@ class MIPVerifyInstaller(Installer):
         assert libjulia_path is not None
         julia_dir = libjulia_path.parent.parent
 
+        julia_cmd = "./julia --project=. -e"
+
         envvars = env.vars()
         commands = [
             "set -ex",
@@ -47,21 +44,30 @@ class MIPVerifyInstaller(Installer):
             "cd mipverify",
             f"cp -r {julia_dir} .",
             f"ln -s {julia_dir}/bin/julia julia",
-            './julia --project=. -e \'using Pkg; Pkg.add("Gurobi"); Pkg.build("Gurobi")\'',
-            './julia --project=. -e \'using Pkg; Pkg.add("MathOptInterface"); Pkg.build("MathOptInterface")\'',
-            './julia --project=. -e \'using Pkg; Pkg.add("JuMP"); Pkg.build("JuMP")\'',
-            './julia --project=. -e \'using Pkg; Pkg.add("MAT"); Pkg.build("MAT")\'',
-            f'./julia --project=. -e \'using Pkg; Pkg.add(PackageSpec(url="https://github.com/vtjeng/MIPVerify.jl", rev="{commit_hash}"))\'',
-            "./julia --project=. -e 'using Pkg; Pkg.update(); Pkg.precompile()'",
+            (
+                f"{julia_cmd} '"
+                "using Pkg;"
+                'Pkg.add("Gurobi");'
+                'Pkg.add("MathOptInterface");'
+                'Pkg.add("JuMP");'
+                'Pkg.add("MAT");'
+                'Pkg.add("GLPK");'
+                'Pkg.add("HiGHS");'
+                'Pkg.add(name="MIPVerify", version="0.3");'
+                "Pkg.build();"
+                "Pkg.precompile();"
+                "'"
+            ),
+            f"{julia_cmd} 'using Pkg; Pkg.update(); Pkg.precompile()'",
         ]
         install_script = "; ".join(commands)
         proc = sp.run(install_script, shell=True, env=envvars)
         if proc.returncode != 0:
-            raise InstallError(f"Installation of MIPVerify failed")
+            raise InstallError("Installation of MIPVerify failed")
 
         with open(installation_path / "mipverify", "w+") as f:
             f.write(
-                mipverify_runner.format(
+                MIPVERIFY_RUNNER.format(
                     venv_path=verifier_venv_path,
                     gurobi_home=envvars.get("GUROBI_HOME", "."),
                 )
@@ -71,7 +77,7 @@ class MIPVerifyInstaller(Installer):
 
 class JuliaInstaller(Installer):
     def run(self, env: Environment, dependency: Dependency):
-        version = "1.6.1"
+        version = "1.7.2"
         major_minor = ".".join(version.split(".")[:2])
 
         cache_dir = env.cache_dir / f"julia-{version}"
@@ -83,21 +89,27 @@ class JuliaInstaller(Installer):
         if dependency.is_installed(env):
             return
 
+        julia_url = (
+            "https://julialang-s3.julialang.org/bin/linux/x64/"
+            f"{major_minor}/julia-{version}-linux-x86_64.tar.gz"
+        )
         commands = [
             "set -ex",
             f"cd {cache_dir}",
-            f"curl -o julia-{version}.tar.gz -L https://julialang-s3.julialang.org/bin/linux/x64/{major_minor}/julia-{version}-linux-x86_64.tar.gz",
+            f"curl -o julia-{version}.tar.gz -L {julia_url}",
             f"tar xf julia-{version}.tar.gz",
         ]
         install_script = "; ".join(commands)
         proc = sp.run(install_script, shell=True, env=env.vars())
         if proc.returncode != 0:
-            raise InstallError(f"Installation of julia failed")
+            raise InstallError("Installation of julia failed")
 
 
 def install(env: Environment):
     zlib_installer = GNUInstaller(
-        "zlib", "1.2.11", "https://www.zlib.net/zlib-1.2.11.tar.xz"
+        "zlib",
+        "1.2.12",
+        "https://github.com/madler/zlib/archive/refs/tags/v1.2.12.tar.gz",
     )
     gurobi_installer = GurobiInstaller("9.1.2")
     env.ensure_dependencies(
@@ -106,6 +118,7 @@ def install(env: Environment):
             installer=MIPVerifyInstaller(),
             dependencies=(
                 ProgramDependency("julia", installer=JuliaInstaller()),
+                LibraryDependency("libjulia", installer=JuliaInstaller()),
                 ProgramDependency("git"),
                 HeaderDependency("zlib.h", installer=zlib_installer),
                 LibraryDependency("libz", installer=zlib_installer),
