@@ -3,15 +3,10 @@ from __future__ import annotations
 import subprocess as sp
 import sys
 
-from ..environment import (
-    Environment,
-    Dependency,
-    ProgramDependency,
-    Installer,
-)
 from ...errors import InstallError, UninstallError
+from ..environment import Dependency, Environment, Installer, ProgramDependency
 
-runner_template = """#!{python_venv}/bin/python
+RUNNER_TEMPLATE = """#!{python_venv}/bin/python
 import argparse
 import numpy as np
 
@@ -84,7 +79,7 @@ if __name__ == "__main__":
 
 class NnenumInstaller(Installer):
     def run(self, env: Environment, dependency: Dependency):
-        commit_hash = "fd07f2b6c55ca46387954559f40992ae0c9b06b7"
+        commit_hash = "fa1463b6f345ca143662c4143dfb4774e6615672"
         name = "nnenum"
 
         cache_dir = env.cache_dir / f"{name}-{commit_hash}"
@@ -97,6 +92,8 @@ class NnenumInstaller(Installer):
         verifier_venv_path.parent.mkdir(exist_ok=True, parents=True)
 
         python_major_version, python_minor_version = sys.version_info[:2]
+        python_version = f"python{python_major_version}.{python_minor_version}"
+        site_packages_dir = f"{verifier_venv_path}/lib/{python_version}/site-packages/"
 
         envvars = env.vars()
         commands = [
@@ -106,14 +103,26 @@ class NnenumInstaller(Installer):
             f"python -m venv {name}",
             f". {name}/bin/activate",
             "pip install --upgrade pip",
+            (
+                "pip install"
+                ' "numpy>=1.19,<1.22"'
+                ' "onnx>=1.8,<1.11"'
+                ' "onnxruntime>=1.7,<1.11"'
+                ' "scipy>=1.4.1<1.8"'
+                ' "threadpoolctl==2.1.0"'
+                ' "skl2onnx==1.7.0"'
+                ' "swiglpk"'
+                ' "termcolor"'
+                ' "protobuf<=3.20"'
+            ),
             f"cd {cache_dir}",
-            f"rm -rf {name}",
-            "git clone https://github.com/stanleybak/nnenum.git",
+            f"if [ ! -e {name} ]",
+            "then git clone https://github.com/stanleybak/nnenum.git",
             f"cd {name}",
             f"git checkout {commit_hash}",
-            # "pip install -r requirements.txt",
-            'pip install "numpy>=1.19,<1.22" "onnx>=1.8,<1.11" "onnxruntime>=1.7,<1.11" "scipy>=1.4.1<1.8" "threadpoolctl==2.1.0" "skl2onnx==1.7.0" "swiglpk" "termcolor"',
-            f"cp -r src/nnenum {verifier_venv_path}/lib/python{python_major_version}.{python_minor_version}/site-packages/",
+            f"else cd {name}",
+            "fi",
+            f"cp -r src/nnenum {site_packages_dir}",
         ]
         install_script = "; ".join(commands)
         proc = sp.run(install_script, shell=True, env=envvars)
@@ -121,7 +130,7 @@ class NnenumInstaller(Installer):
             raise InstallError(f"Installation of {name} failed")
 
         with open(installation_path / name, "w+") as f:
-            f.write(runner_template.format(python_venv=verifier_venv_path))
+            f.write(RUNNER_TEMPLATE.format(python_venv=verifier_venv_path))
         (installation_path / name).chmod(0o700)
 
 
