@@ -3,12 +3,11 @@
 import argparse
 import importlib
 import pkgutil
-
 from pathlib import Path
 
-from .. import verifiers
 from .. import __version__
 from .. import logging_utils as logging
+from .. import verifiers
 
 
 class HelpFormatter(argparse.HelpFormatter):
@@ -16,24 +15,22 @@ class HelpFormatter(argparse.HelpFormatter):
         if not action.option_strings:
             (metavar,) = self._metavar_formatter(action, action.dest)(1)
             return metavar
-        else:
-            parts = []
+        parts = []
+        if action.nargs == 0:
             # if the Optional doesn't take a value, format is:
             #    -s, --long
-            if action.nargs == 0:
-                parts.extend(action.option_strings)
-
+            parts.extend(action.option_strings)
+        else:
             # if the Optional takes a value, format is:
             #    -s ARGS, --long ARGS
             # change to
             #    -s, --long ARGS
-            else:
-                default = action.dest.upper()
-                args_string = self._format_args(action, default)
-                for option_string in action.option_strings:
-                    parts.append("%s" % option_string)
-                parts[-1] += " %s" % args_string
-            return ", ".join(parts)
+            default = action.dest.upper()
+            args_string = self._format_args(action, default)
+            for option_string in action.option_strings:
+                parts.append(option_string)
+            parts[-1] += f" {args_string}"
+        return ", ".join(parts)
 
 
 class AppendNetwork(argparse.Action):
