@@ -2,7 +2,6 @@
 """
 import argparse
 import logging
-import os
 import sys
 
 
@@ -16,7 +15,10 @@ def add_arguments(parser: argparse.ArgumentParser):
         help="show messages with finer-grained information",
     )
     verbosity_group.add_argument(
-        "-q", "--quiet", action="store_true", help="suppress non-essential messages"
+        "-q",
+        "--quiet",
+        action="store_true",
+        help="suppress non-essential messages",
     )
 
 
@@ -24,24 +26,18 @@ def initialize(name: str, args: argparse.Namespace) -> logging.Logger:
     logger = logging.getLogger(name)
     logger.propagate = False
 
-    TF_CPP_MIN_LOG_LEVEL = os.environ.get("TF_CPP_MIN_LOG_LEVEL", None)
-
     if args.debug:
         logger.setLevel(logging.DEBUG)
-        os.environ["TF_CPP_MIN_LOG_LEVEL"] = TF_CPP_MIN_LOG_LEVEL or "1"
     elif args.verbose:
-        os.environ["TF_CPP_MIN_LOG_LEVEL"] = TF_CPP_MIN_LOG_LEVEL or "2"
         logger.setLevel(logging.INFO)
     elif args.quiet:
-        os.environ["TF_CPP_MIN_LOG_LEVEL"] = TF_CPP_MIN_LOG_LEVEL or "2"
         logger.setLevel(logging.ERROR)
     else:
-        os.environ["TF_CPP_MIN_LOG_LEVEL"] = TF_CPP_MIN_LOG_LEVEL or "2"
         logger.setLevel(logging.WARNING)
 
-    formatter = logging.Formatter(f"%(levelname)-8s %(asctime)s (%(name)s) %(message)s")
+    formatter = logging.Formatter("%(levelname)-8s %(asctime)s (%(name)s) %(message)s")
 
-    console_handler = logging.StreamHandler(stream=sys.stdout)
+    console_handler = logging.StreamHandler(stream=sys.stderr)
     console_handler.setLevel(logging.DEBUG)
     console_handler.setFormatter(formatter)
     logger.addHandler(console_handler)
@@ -49,8 +45,4 @@ def initialize(name: str, args: argparse.Namespace) -> logging.Logger:
     return logger
 
 
-def getLogger(name: str) -> logging.Logger:
-    return logging.getLogger(name)
-
-
-__all__ = ["add_arguments", "getLogger", "initialize"]
+__all__ = ["add_arguments", "initialize"]
