@@ -1,15 +1,14 @@
-import numpy as np
-
 from copy import copy
 
+import numpy as np
+
+from ... import OperationGraph, operations
 from .base import Simplifier
-from ... import operations, OperationGraph
 
 
 class BundleTranspose(Simplifier):
     def visit_Gemm(self, operation: operations.Gemm) -> operations.Gemm:
         if not all(len(s) > 1 for s in OperationGraph([operation]).input_shape):
-            # ensure that all
             return operation
         if operation.transpose_a:  # TODO : what if operation.b is the Operation?
             return operation
@@ -60,3 +59,6 @@ class BundleTranspose(Simplifier):
         operation.b = b[weights_permutation]
         operation.transpose_b = False
         return operation
+
+
+__all__ = ["BundleTranspose"]
