@@ -1,20 +1,21 @@
-import numpy as np
+from __future__ import annotations
 
 from copy import deepcopy
+from typing import Any, Dict, Optional, Sequence, Tuple, Union
+
+import numpy as np
 
 from ..graph import OperationGraph
 from ..operations import Input, Operation
-from ..visitors import GetInputDetails
-
 from .base import OperationTransformer
 
 
 class DropPrefix(OperationTransformer):
-    def __init__(self, prefix_graph):
+    def __init__(self, prefix_graph: OperationGraph):
+        super().__init__()
         self.prefix_graph = prefix_graph
-        self._cache = {}
 
-    def visit(self, operation):
+    def visit(self, operation: Operation) -> Operation:
         if operation not in self._cache:
             if operation not in self.prefix_graph.output_operations:
                 result = super().visit(operation)
@@ -29,29 +30,31 @@ class DropPrefix(OperationTransformer):
             self._cache[operation] = result
         return self._cache[operation]
 
-    def generic_visit(self, operation):
-        kwargs = {}
+    def generic_visit(self, operation: Operation) -> Operation:
+        kwargs: Dict[str, Any] = {}
         for name, value in operation.__dict__.items():
             if isinstance(value, Operation):
-                new_value = self.visit(value)
-                kwargs[name] = new_value
+                kwargs[name] = self.visit(value)
             else:
                 kwargs[name] = deepcopy(value)
         return operation.__class__(**kwargs)
 
 
 class Slicer(OperationTransformer):
-    def __init__(self, start, stop):
-        self.start = start
+    def __init__(self, start: Optional[int], stop: Optional[int]):
+        super().__init__(cached=False)
+        # TODO : This class needs a refactor
+        self.start = start or 0
         self.stop = stop
 
         self.index = 0
         self.length = 0
-        self._index_cache = {}
-        self.current_pass = None
-        self._cache = {}
+        self._index_cache: Dict[
+            Operation, Tuple[Union[float, int], Union[float, int], Operation]
+        ] = {}
+        self.current_pass: Optional[str] = None
 
-    def visit(self, operation):
+    def visit(self, operation: Operation) -> Union[Operation, Sequence[Operation]]:
         is_first = False
         if self.current_pass is None:
             is_first = True
@@ -68,6 +71,8 @@ class Slicer(OperationTransformer):
             outputs = []
             if self.stop is None:
                 outputs.append(super().visit(operation))
+            elif self.stop == 0:
+                outputs = []
             else:
                 for pi, ni, op in self._index_cache.values():
                     if min(self.stop, self.length) in (pi + 1, ni + 1):
@@ -90,17 +95,29 @@ class Slicer(OperationTransformer):
         else:
             raise ValueError()
 
-    def generic_visit(self, operation):
+    def generic_visit(self, operation: Operation) -> Operation:
         if self.current_pass == "indexing":
             self.index -= 1
             self.length = max(self.length, -self.index)
             if operation not in self._index_cache:
-                self._index_cache[operation] = [float("inf"), float("-inf"), operation]
-            pos_index, neg_index, _ = self._index_cache[operation]
-            self._index_cache[operation][1] = max(neg_index, self.index)
+                self._index_cache[operation] = (
+                    float("inf"),
+                    float("-inf"),
+                    operation,
+                )
+            pos_index, neg_index, op = self._index_cache[operation]
+            self._index_cache[operation] = (
+                pos_index,
+                max(neg_index, self.index),
+                op,
+            )
             result = super().generic_visit(operation)
-            pos_index, neg_index, _ = self._index_cache[operation]
-            self._index_cache[operation][0] = min(pos_index, self.length + self.index)
+            pos_index, neg_index, op = self._index_cache[operation]
+            self._index_cache[operation] = (
+                min(pos_index, self.length + self.index),
+                neg_index,
+                op,
+            )
             self.index += 1
             return result
         elif self.current_pass == "selection":
@@ -110,11 +127,10 @@ class Slicer(OperationTransformer):
             ):
                 y = OperationGraph([operation]).output_details
                 return Input(y[0].shape, y[0].dtype)
-            kwargs = {}
+            kwargs: Dict[str, Any] = {}
             for name, value in operation.__dict__.items():
                 if isinstance(value, Operation):
-                    new_value = self.visit(value)
-                    kwargs[name] = new_value
+                    kwargs[name] = self.visit(value)
                 elif isinstance(value, (tuple, list, set)):
                     new_value = []
                     for value_ in value:
