@@ -1,4 +1,5 @@
+from .errors import DNNVExpressionError, NonConcreteExpressionError
 from .expressions import *
-from .parser import parse
+from .parser import *
 from .transformers import ExpressionTransformer
 from .visitors import ExpressionVisitor
