@@ -1,16 +1,24 @@
 from __future__ import annotations
 
-from typing import Optional, Set, Tuple
+from typing import Optional, Set, Tuple, Union
 
+from ..expressions import *
+from ..visitors.inference import DetailsInference
 from .base import GenericExpressionTransformer
 from .lift_ifthenelse import LiftIfThenElse
 from .remove_ifthenelse import RemoveIfThenElse
 from .substitute_calls import SubstituteCalls
-from ..expressions import *
-from ..visitors.inference import DetailsInference
 
 
 class DnfTransformer(GenericExpressionTransformer):
+    def __init__(self):
+        super().__init__()
+        self._infer_expression_details = lambda: None
+
+    def _lazy_inference(self):
+        self._infer_expression_details()
+        self._infer_expression_details = lambda: None
+
     def visit(self, expression: Expression) -> Expression:
         if self._top_level:
             expression = expression.propagate_constants()
@@ -24,22 +32,28 @@ class DnfTransformer(GenericExpressionTransformer):
                 expression, Symbol
             ):
                 expression = Or(And(expression))
-            DetailsInference().visit(expression)
+            self._infer_expression_details = (
+                lambda expression=expression: DetailsInference().visit(expression)
+            )
         expression = super().visit(expression)
         return expression
 
-    def visit_And(self, expression: And) -> Or:
+    def visit_And(self, expression: And) -> Union[Constant, Or]:
         disjunction: Optional[Or] = None
         expressions: Set[Expression] = set()
         for expr in expression.expressions:
             expr = self.visit(expr)
+            if expr.is_concrete:
+                if expr.value:
+                    continue
+                return Constant(False)
             if disjunction is None and isinstance(expr, Or):
                 disjunction = expr
             else:
                 expressions.add(expr)
         if disjunction is None:
             if len(expressions) == 0:
-                return Constant(False)
+                return Constant(True)
             return Or(And(*expressions))
         elif len(expressions) == 0:
             return disjunction
@@ -61,20 +75,25 @@ class DnfTransformer(GenericExpressionTransformer):
                 disjuncts = new_disjuncts
         return Or(*[And(*disjunct) for disjunct in disjuncts])
 
-    def visit_Exists(self, expression: Exists):
+    def visit_Exists(self, expression: Exists) -> Union[Constant, Or, Symbol]:
         # TODO : should this do other things ?
         expr = self.visit(expression.expression)
+        assert isinstance(expr, (Constant, Or, Symbol))
         return expr
 
-    def visit_Forall(self, expression: Forall):
+    def visit_Forall(self, expression: Forall) -> Union[Constant, Or, Symbol]:
         # TODO : should this do other things ?
         expr = self.visit(expression.expression)
+        assert isinstance(expr, (Constant, Or, Symbol))
         return expr
 
-    def visit_Implies(self, expression: Implies) -> Or:
-        return self.visit(Or(~expression.expr1, expression.expr2))
+    def visit_Implies(self, expression: Implies) -> Union[Constant, Or]:
+        assert isinstance(expression.expr1, LogicalExpression)
+        expr = self.visit(Or(~expression.expr1, expression.expr2))
+        assert isinstance(expr, (Constant, Or))
+        return expr
 
-    def visit_Not(self, expression: Not) -> Or:
+    def visit_Not(self, expression: Not) -> Union[Constant, Or]:
         expr = expression.expr
         if isinstance(
             expr,
@@ -95,6 +114,7 @@ class DnfTransformer(GenericExpressionTransformer):
                 LessThan: GreaterThanOrEqual,
                 LessThanOrEqual: GreaterThan,
             }
+            self._lazy_inference()
             if expr.expr1 in expr.ctx.shapes and expr.expr2 in expr.ctx.shapes:
                 import numpy as np
 
@@ -102,7 +122,7 @@ class DnfTransformer(GenericExpressionTransformer):
                     expr.ctx.shapes[expr.expr1], expr.ctx.shapes[expr.expr2]
                 )
                 if np.all(np.asarray(output_shape) == 1):
-                    return self.visit(
+                    expr = self.visit(
                         Or(
                             opposite_comparison[type(expr)](
                                 expr.expr1, expr.expr2, ctx=expr.ctx
@@ -110,6 +130,8 @@ class DnfTransformer(GenericExpressionTransformer):
                             ctx=expr.ctx,
                         )
                     )
+                    assert isinstance(expr, (Constant, Or))
+                    return expr
                 expr1 = expr.expr1
                 if expr.ctx.shapes[expr1] != output_shape:
                     expr1 = Constant(np.broadcast_to, ctx=expr.ctx)(
@@ -120,30 +142,39 @@ class DnfTransformer(GenericExpressionTransformer):
                     expr2 = Constant(np.broadcast_to, ctx=expr.ctx)(
                         expr2, Constant(output_shape, ctx=expr.ctx)
                     )
-                return self.visit(
+                expr = self.visit(
                     Or(
                         *(
                             opposite_comparison[type(expr)](
                                 expr1[idx], expr2[idx], ctx=expr.ctx
                             )
-                            for idx in np.ndindex(output_shape)
+                            for idx in np.ndindex(*output_shape)
                         ),
                         ctx=expr.ctx,
                     )
                 )
+                assert isinstance(expr, (Constant, Or))
+                return expr
         elif isinstance(expression.expr, Symbol):
             return Or(And(Not(expression.expr)))
 
+        assert isinstance(expression.expr, LogicalExpression)
         result = ~expression.expr
         if isinstance(result, Not):
             # TODO : should this be an error?
             return result
-        return self.visit(result)
+        expr = self.visit(result)
+        assert isinstance(expr, (Constant, Or))
+        return expr
 
-    def visit_Or(self, expression: Or) -> Or:
+    def visit_Or(self, expression: Or) -> Union[Constant, Or]:
         expressions: Set[Expression] = set()
         for expr in expression.expressions:
             expr = self.visit(expr)
+            if expr.is_concrete:
+                if expr.value:
+                    return Constant(True)
+                continue
             if isinstance(expr, Or):
                 expressions = expressions.union(expr.expressions)
             else:
