@@ -1,42 +1,60 @@
 import logging
 import os
 import tempfile
-
 from abc import ABC, abstractmethod
 from contextlib import contextmanager
 from functools import partial
-from typing import Any, Dict, Generator, List, Optional, Tuple, Type, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Generator,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-from dnnv.properties import Expression
+from dnnv.properties import Expression, LogicalExpression
 
 from .errors import VerifierError, VerifierTranslatorError
-from .executors import VerifierExecutor, CommandLineExecutor
+from .executors import CommandLineExecutor, VerifierExecutor
 from .reductions import (
-    Property,
-    Reduction,
-    IOPolytopeReduction,
     HalfspacePolytope,
     HyperRectangle,
+    IOPolytopeReduction,
+    Property,
+    Reduction,
 )
-from .results import SAT, UNSAT, UNKNOWN, PropertyCheckResult
+from .results import SAT, UNSAT, PropertyCheckResult
 
 
 class Parameter:
     def __init__(
         self,
-        dtype: Type,
+        dtype: Callable[[Any], Any],
         default: Optional[Any] = None,
         choices: Optional[List[Any]] = None,
         help: Optional[str] = None,
     ):
-        self.type = dtype
+        self.type: Callable[[Any], Any] = dtype
         if dtype == bool:
-            self.type = lambda x: x not in ["False", "false", "0", "F", "f", False, 0]
+            self.type = lambda x: x not in [
+                "False",
+                "false",
+                "0",
+                "F",
+                "f",
+                False,
+                0,
+            ]
         self.default = self.type(default) if default is not None else None
         self.choices = choices
         self.help = help
 
-    def as_type(self, value):
+    def as_type(self, value: Any):
         return self.type(value) if value is not None else None
 
 
@@ -54,10 +72,10 @@ class Verifier(ABC):
             f"{type(self).__module__}.{type(self).__qualname__}"
         )
         self.property = dnn_property.propagate_constants()
-        for key, value in kwargs.items():
+        for key in kwargs:
             if key not in self.__class__.parameters:
                 raise self.verifier_error(f"Unknown parameter: {key}")
-        self.parameters = {
+        self.parameter_values: Dict[str, Any] = {
             name: param.as_type(kwargs.get(name, param.default))
             for name, param in self.__class__.parameters.items()
         }
@@ -65,6 +83,8 @@ class Verifier(ABC):
     @classmethod
     def is_installed(cls) -> bool:
         verifier = getattr(cls, "EXE", cls.__qualname__.lower())
+        if os.path.isfile(verifier) and os.access(verifier, os.X_OK):
+            return True
         for path in os.environ["PATH"].split(os.pathsep):
             exe = os.path.join(path, verifier)
             if os.path.isfile(exe) and os.access(exe, os.X_OK):
@@ -73,7 +93,7 @@ class Verifier(ABC):
 
     @contextmanager
     def contextmanager(self):
-        yield
+        yield self
 
     @classmethod
     def verify(
@@ -90,31 +110,38 @@ class Verifier(ABC):
         return self.parse_results(prop, results)
 
     def reduce_property(self) -> Generator[Property, None, None]:
-        for subproperty in self.reduction(
-            reduction_error=self.translator_error
-        ).reduce_property(~self.property):
+        assert isinstance(self.property, LogicalExpression)
+        for subproperty in self.reduction().reduce_property(~self.property):
             yield subproperty
 
     def run(self) -> Tuple[PropertyCheckResult, Optional[Any]]:
         if self.property.is_concrete:
-            if self.property.value == True:
+            if self.property.value:
                 self.logger.warning("Property is trivially UNSAT.")
                 return UNSAT, None
-            else:
-                self.logger.warning("Property is trivially SAT.")
-                return SAT, None
+            self.logger.warning("Property is trivially SAT.")
+            return SAT, None
         orig_tempdir = tempfile.tempdir
         try:
             with tempfile.TemporaryDirectory() as tempdir:
                 tempfile.tempdir = tempdir
                 result = UNSAT
                 for subproperty in self.reduce_property():
-                    subproperty_result, cex = self.check(subproperty)
+                    is_trivial, *trivial_result = subproperty.is_trivial()
+                    if is_trivial:
+                        subproperty_result, cex = trivial_result[0]
+                        self.logger.warning(
+                            "Property is trivially %s.", subproperty_result
+                        )
+                    else:
+                        subproperty_result, cex = self.check(subproperty)
                     result |= subproperty_result
                     if result == SAT:
-                        self.logger.debug("SAT! Validating counter example.")
                         if cex is not None:
+                            self.logger.debug("SAT! Validating counter example.")
                             self.validate_counter_example(subproperty, cex)
+                        else:
+                            self.logger.warning("SAT result without counter example.")
                         return result, cex
         finally:
             tempfile.tempdir = orig_tempdir
@@ -127,13 +154,13 @@ class Verifier(ABC):
         return is_valid
 
     @abstractmethod
-    def build_inputs(self, prop: Property) -> Tuple[Any, ...]:
+    def build_inputs(self, prop: Property) -> Sequence:  # pragma: no cover
         raise NotImplementedError()
 
     @abstractmethod
     def parse_results(
         self, prop: Property, results: Any
-    ) -> Tuple[PropertyCheckResult, Optional[Any]]:
+    ) -> Tuple[PropertyCheckResult, Optional[Any]]:  # pragma: no cover
         raise NotImplementedError()
 
 
