@@ -1,15 +1,23 @@
 from abc import ABC, abstractmethod
-from typing import Any, Iterator, Optional, Tuple, Type
+from typing import Any, Iterator, Optional, Tuple, Type, Union
 
 from dnnv.errors import DNNVError
 from dnnv.properties import Expression
 
+from ..results import PropertyCheckResult
+
 
 class ReductionError(DNNVError):
     pass
 
 
-class Property:
+class Property(ABC):
+    @abstractmethod
+    def is_trivial(
+        self,
+    ) -> Union[Tuple[bool], Tuple[bool, Tuple[PropertyCheckResult, Any]]]:
+        raise NotImplementedError()
+
     @abstractmethod
     def validate_counter_example(self, cex: Any) -> Tuple[bool, Optional[str]]:
         raise NotImplementedError()
@@ -23,7 +31,7 @@ class Reduction(ABC):
         self.reduction_error = reduction_error
 
     @abstractmethod
-    def reduce_property(self, phi: Expression) -> Iterator[Property]:
+    def reduce_property(self, expression: Expression) -> Iterator[Property]:
         raise NotImplementedError()
 
 
