@@ -18,7 +18,11 @@ class PropertyCheckResult:
     def __and__(self, other):
         if not isinstance(other, PropertyCheckResult):
             return NotImplemented
-        if self not in (SAT, UNSAT, UNKNOWN) or other not in (SAT, UNSAT, UNKNOWN):
+        if self not in (SAT, UNSAT, UNKNOWN) or other not in (
+            SAT,
+            UNSAT,
+            UNKNOWN,
+        ):
             return UNKNOWN
         if self == UNSAT or other == UNSAT:
             return UNSAT
@@ -29,7 +33,11 @@ class PropertyCheckResult:
     def __or__(self, other):
         if not isinstance(other, PropertyCheckResult):
             return NotImplemented
-        if self not in (SAT, UNSAT, UNKNOWN) or other not in (SAT, UNSAT, UNKNOWN):
+        if self not in (SAT, UNSAT, UNKNOWN) or other not in (
+            SAT,
+            UNSAT,
+            UNKNOWN,
+        ):
             return UNKNOWN
         if self == SAT or other == SAT:
             return SAT
