@@ -1,11 +1,13 @@
 import shutil
+from functools import partial
+from pathlib import Path
 
 from dnnv.verifiers.common.base import Parameter, Verifier
 from dnnv.verifiers.common.executors import VerifierExecutor
 from dnnv.verifiers.common.reductions import (
-    IOPolytopeReduction,
     HalfspacePolytope,
     HyperRectangle,
+    IOPolytopeReduction,
 )
 from dnnv.verifiers.common.results import UNKNOWN
 from dnnv.verifiers.common.utils import as_layers
@@ -13,8 +15,6 @@ from dnnv.verifiers.planet.errors import PlanetTranslatorError
 from dnnv.verifiers.planet.utils import to_rlv_file
 from dnnv.verifiers.reluplex.errors import ReluplexTranslatorError
 from dnnv.verifiers.reluplex.utils import to_nnet_file
-from functools import partial
-from pathlib import Path
 
 from .errors import VnnlibTranslatorError
 from .utils import to_vnnlib_onnx_file, to_vnnlib_property_file
@@ -67,7 +67,7 @@ class Convert(Verifier):
         paths = []
         if self.parameters.get("to") == "nnet":
             layers = as_layers(
-                prop.suffixed_op_graph(),
+                prop.suffixed_op_graph().simplify(),
                 translator_error=self.translator_error,
             )
             paths.append(
@@ -81,7 +81,7 @@ class Convert(Verifier):
             )
         elif self.parameters.get("to") == "rlv":
             layers = as_layers(
-                prop.suffixed_op_graph(),
+                prop.suffixed_op_graph().simplify(),
                 translator_error=self.translator_error,
             )
             paths.append(
@@ -97,7 +97,8 @@ class Convert(Verifier):
             paths.append(
                 Path(
                     to_vnnlib_onnx_file(
-                        prop.op_graph, translator_error=self.translator_error
+                        prop.op_graph.simplify(),
+                        translator_error=self.translator_error,
                     )
                 )
             )
@@ -110,7 +111,6 @@ class Convert(Verifier):
                     )
                 )
             )
-            # TODO : create ONNX model
         dest: Path = self.parameters.get("dest")
         dest.mkdir(exist_ok=True, parents=True)
         for path in paths:
