@@ -1,16 +1,16 @@
-import numpy as np
 import tempfile
+from functools import partial
+
+import numpy as np
 
 from dnnv.verifiers.common.base import Parameter, Verifier
-from dnnv.verifiers.common.reductions import IOPolytopeReduction, HalfspacePolytope
-from dnnv.verifiers.common.results import SAT, UNSAT, UNKNOWN
-from functools import partial
+from dnnv.verifiers.common.reductions import HalfspacePolytope, IOPolytopeReduction
+from dnnv.verifiers.common.results import SAT, UNKNOWN, UNSAT
 
 from .errors import MarabouError, MarabouTranslatorError
 
 
 class Marabou(Verifier):
-    EXE = "marabou.py"
     reduction = partial(IOPolytopeReduction, HalfspacePolytope, HalfspacePolytope)
     translator_error = MarabouTranslatorError
     verifier_error = MarabouError
@@ -27,7 +27,7 @@ class Marabou(Verifier):
         with tempfile.NamedTemporaryFile(
             mode="w+", suffix=".onnx", delete=False
         ) as onnx_model_file:
-            prop.op_graph.export_onnx(onnx_model_file.name)
+            prop.op_graph.simplify().export_onnx(onnx_model_file.name)
 
         lb, ub = prop.input_constraint.as_bounds()
         A_in, b_in = prop.input_constraint.as_matrix_inequality()
@@ -43,19 +43,21 @@ class Marabou(Verifier):
         ) as output_file:
             self._tmp_output_file = output_file
         args = (
-            "marabou.py",
+            "marabou",
             onnx_model_file.name,
             constraint_file.name,
             "-o",
             self._tmp_output_file.name,
-        ) + tuple(f"--{k}={v}" for k, v in self.parameters.items() if v is not None)
+        ) + tuple(
+            f"--{k}={v}" for k, v in self.parameter_values.items() if v is not None
+        )
         return args
 
     def parse_results(self, prop, results):
-        result, cinput = np.load(self._tmp_output_file.name, allow_pickle=True)
-        if result == False:
+        result_str, cinput = np.load(self._tmp_output_file.name, allow_pickle=True)
+        if result_str == "unsat":
             return UNSAT, None
-        elif result == True:
+        elif result_str == "sat":
             input_shape, input_dtype = prop.op_graph.input_details[0]
             cex = cinput.reshape(input_shape).astype(input_dtype)
             return SAT, cex
