@@ -1,10 +1,11 @@
+from functools import partial
+
 import numpy as np
 
 from dnnv.verifiers.common.base import Parameter, Verifier
-from dnnv.verifiers.common.reductions import IOPolytopeReduction, HalfspacePolytope
-from dnnv.verifiers.common.results import SAT, UNSAT, UNKNOWN
+from dnnv.verifiers.common.reductions import HalfspacePolytope, IOPolytopeReduction
+from dnnv.verifiers.common.results import SAT, UNKNOWN, UNSAT
 from dnnv.verifiers.common.utils import as_layers
-from functools import partial
 
 from .errors import NeurifyError, NeurifyTranslatorError
 from .utils import to_neurify_inputs
@@ -21,18 +22,18 @@ class Neurify(Verifier):
 
     def build_inputs(self, prop):
         if prop.input_constraint.num_variables > 1:
-            raise NeurifyTranslatorError(
+            raise self.translator_error(
                 "Unsupported network: More than 1 input variable"
             )
         layers = as_layers(
-            prop.suffixed_op_graph(),
-            translator_error=NeurifyTranslatorError,
+            prop.suffixed_op_graph().simplify(),
+            translator_error=self.translator_error,
         )
         neurify_inputs = to_neurify_inputs(
             prop.input_constraint,
             layers,
             # dirname=dirname,
-            translator_error=NeurifyTranslatorError,
+            translator_error=self.translator_error,
         )
         return (
             "neurify",
@@ -41,13 +42,15 @@ class Neurify(Verifier):
             "-x",
             neurify_inputs["input_path"],
             "-sl",
-            "0.0000000000001",  # TODO: remove magic number
+            "0.000000000001",  # TODO: remove magic number
             "-I",
             neurify_inputs["input_interval_path"],
             "-H",
             neurify_inputs["input_hpoly_path"],
             "-v",
-        ) + tuple(f"--{k}={v}" for k, v in self.parameters.items() if v is not None)
+        ) + tuple(
+            f"--{k}={v}" for k, v in self.parameter_values.items() if v is not None
+        )
 
     def parse_results(self, prop, results):
         stdout, stderr = results
