@@ -1,13 +1,13 @@
-import numpy as np
 import os
 import tempfile
-
 from contextlib import contextmanager
 from functools import partial
 
+import numpy as np
+
 from dnnv.verifiers.common.base import Parameter, Verifier
-from dnnv.verifiers.common.reductions import IOPolytopeReduction, HalfspacePolytope
-from dnnv.verifiers.common.results import SAT, UNSAT, UNKNOWN
+from dnnv.verifiers.common.reductions import HalfspacePolytope, IOPolytopeReduction
+from dnnv.verifiers.common.results import SAT, UNKNOWN, UNSAT
 
 from .errors import NnenumError, NnenumTranslatorError
 
@@ -70,10 +70,10 @@ class Nnenum(Verifier):
             self._tmp_output_file.name,
         )
         if (
-            "num_processes" in self.parameters
-            and self.parameters["num_processes"] is not None
+            "num_processes" in self.parameter_values
+            and self.parameter_values["num_processes"] is not None
         ):
-            value = self.parameters["num_processes"]
+            value = self.parameter_values["num_processes"]
             args += (f"--num_processes={value}",)
         return args
 
