@@ -1,10 +1,11 @@
+from functools import partial
+
 import numpy as np
 
 from dnnv.verifiers.common.base import Parameter, Verifier
-from dnnv.verifiers.common.reductions import IOPolytopeReduction, HalfspacePolytope
-from dnnv.verifiers.common.results import SAT, UNSAT, UNKNOWN
+from dnnv.verifiers.common.reductions import HalfspacePolytope, IOPolytopeReduction
+from dnnv.verifiers.common.results import SAT, UNKNOWN, UNSAT
 from dnnv.verifiers.common.utils import as_layers
-from functools import partial
 
 from .errors import PlanetError, PlanetTranslatorError
 from .layers import PLANET_LAYER_TYPES
@@ -18,18 +19,17 @@ class Planet(Verifier):
 
     def build_inputs(self, prop):
         if prop.input_constraint.num_variables > 1:
-            raise ReluplexTranslatorError(
+            raise self.translator_error(
                 "Unsupported network: More than 1 input variable"
             )
         layers = as_layers(
-            prop.suffixed_op_graph(),
+            prop.suffixed_op_graph().simplify(),
             extra_layer_types=PLANET_LAYER_TYPES,
             translator_error=self.translator_error,
         )
         rlv_file_name = to_rlv_file(
             prop.input_constraint,
             layers,
-            # dirname=dirname,
             translator_error=self.translator_error,
         )
         return "planet", rlv_file_name
