@@ -1,7 +1,7 @@
 import numpy as np
 
 from dnnv.verifiers.common.base import Parameter, Verifier
-from dnnv.verifiers.common.results import SAT, UNSAT, UNKNOWN
+from dnnv.verifiers.common.results import SAT, UNKNOWN, UNSAT
 from dnnv.verifiers.common.utils import as_layers
 
 from .errors import ReluplexError, ReluplexTranslatorError
