@@ -1,8 +1,8 @@
-from dnnv.properties import *
 import numpy as np
 
+from dnnv.properties import *
+
 N = Network("N")
-lb = -np.ones((1, 2))
 ub = np.ones((1, 2))
 
-Forall(x, Implies(lb <= x <= ub, N(x) >= 1))
+Forall(x, Implies(abs(x) <= ub, N(x) >= 1))
