@@ -1,6 +1,5 @@
 import numpy as np
-import onnxruntime
-import pytest
+import onnxruntime.backend
 
 from dnnv.nn.converters.onnx import *
 from dnnv.nn.operations import *
@@ -9,7 +8,7 @@ from dnnv.nn.operations import *
 def test_Dropout_consts():
     x = np.array([3, 4]).astype(np.float32)
     op = Dropout(x)
-    onnx_model = convert(OperationGraph([OutputSelect(op, 0)]))
+    onnx_model = convert(OperationGraph([op]))
 
     results = onnxruntime.backend.run(onnx_model, [])
     assert len(results) == 1
@@ -23,7 +22,7 @@ def test_Dropout_x_is_op():
     x = np.array([3, 4]).astype(np.float32)
     input_op = Input((2,), np.dtype(np.float32))
     op = Dropout(input_op)
-    onnx_model = convert(OperationGraph([OutputSelect(op, 0)]))
+    onnx_model = convert(OperationGraph([op]))
 
     results = onnxruntime.backend.run(onnx_model, [x])
     assert len(results) == 1
