@@ -1,6 +1,7 @@
 import itertools
+
 import numpy as np
-import onnxruntime
+import onnxruntime.backend
 
 from dnnv.nn.converters.onnx import *
 from dnnv.nn.operations import *
